@@ -1,6 +1,6 @@
 import pandas as pd
 
-def CorrMatrixAnalysis(df, dep_feature):
+def CorrMatrixAnalysis(df, dep_feature, output=False):
     '''brief:
             Displays in depth analysis of the correlation between features. Currently only addresses
             correlation of dependent feature to independent features, but will be updated soon.
